@@ -76,22 +76,22 @@ Lines::~Lines(){
 		delete start;
 		start=end;
 	}
-};
+}
 
-inline void Lines::reset(){	akt=start;	};
+inline void Lines::reset(){	akt=start;	}
 
 inline void Lines::getKoord(int& a, int& b, int& c, int& d){
 	a=akt->x1; b=akt->y1;
 	c=akt->x2; d=akt->y2;
 	akt=akt->next;
-};
+}
 
 inline void Lines::setKoord(const int& a, const int& b, const int& c, const int& d){
 	akt->x1=a; akt->y1=b;
 	akt->x2=c; akt->y2=d;
-};
+}
 
-inline void Lines::next(void){ akt=akt->next; };
+inline void Lines::next(void){ akt=akt->next; }
 
 void Lines::turn(const int& w, const int& h){
 	start->x1=end->x1+offx1;
@@ -109,7 +109,7 @@ void Lines::turn(const int& w, const int& h){
 	end->next=start;
 	start=start->next;
 	end=end->next;
-};
+}
 
 
 //-----------------------------------------------------------------------------
