@@ -28,6 +28,7 @@
 #include <kfiledialog.h>
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
+#include <kdebug.h>
 
 #include <stdlib.h>
 #include <assert.h>
@@ -794,7 +795,7 @@ void kSlideShowSaver::loadNextImage()
 
   if (!mImage.load(fpath))
   {
-    printf(i18n("Failed to load image \"%1\"\n").arg(fpath).local8Bit());
+    kdDebug() << "Failed to load image " << fpath << endl;
     mFileList.remove(fname);
     mRandomList.remove(fname);
     if (!mFileList.isEmpty()) loadNextImage();
