@@ -99,9 +99,12 @@ bool KXSConfigDialog::create()
 
     KConfig config(mConfigFile);
 
-    QString xmlFile = XSCREENSAVER_HACKS_DIR;
-    xmlFile += "/config/";
-    xmlFile += mExeName + ".xml";
+    QString xmlFile = "/doesntexist";
+#ifdef XSCREENSAVER_CONFIG_DIR
+    xmlFile = XSCREENSAVER_CONFIG_DIR;
+#endif
+
+    xmlFile += "/" + mExeName + ".xml";
     if ( QFile::exists( xmlFile ) ) {
 	// We can use the xscreensaver xml config files.
 	KXSXml xmlParser(controlLayout);
@@ -208,7 +211,7 @@ void KXSConfigDialog::slotPreviewExited(KProcess *)
 	mKilled = false;
 	mPreviewProc->clearArguments();
 	QString saver;
-	saver.sprintf( "%s -window-id 0x%X", mFilename.latin1(), mPreview->winId() );
+	saver.sprintf( "%s -window-id 0x%lX", mFilename.latin1(), long(mPreview->winId()) );
 	saver += command();
 	kdDebug() << "Command: " <<  saver << endl;
 
@@ -306,13 +309,13 @@ static const KCmdLineOptions options[] =
    {0,0,0}
 };
 
-static char *defaults[] = {
+static const char *defaults[] = {
 #include "XScreenSaver_ad.h"
  0
 };
 
-char *progname = 0;
-char *progclass = "XScreenSaver";
+const char *progname = 0;
+const char *progclass = "XScreenSaver";
 XrmDatabase db;
 
 int main(int argc, char *argv[])
@@ -332,7 +335,7 @@ int main(int argc, char *argv[])
      at least as far as the resource database is concerned.  So,
      put "xscreensaver" in argv[0] while initializing Xt.
    */
-  char *dummyargs[] = { "xscreensaver" };
+  const char *dummyargs[] = { "xscreensaver" };
   int dummyargc = 1;
   progname = dummyargs[0];
 
@@ -340,14 +343,17 @@ int main(int argc, char *argv[])
   XtToolkitInitialize ();
   XtAppContext xtApp = XtCreateApplicationContext ();
   Display *dpy = qt_xdisplay();
-  XtAppSetFallbackResources (xtApp, defaults);
-  XtDisplayInitialize (xtApp, dpy, progname, progclass, 0, 0, &dummyargc, dummyargs);
+  XtAppSetFallbackResources (xtApp, const_cast<char**>(defaults));
+  XtDisplayInitialize (xtApp, dpy, progname, progclass, 0, 0,
+                       &dummyargc,
+                       const_cast<char**>(dummyargs));
   Widget toplevel_shell = XtAppCreateShell (progname, progclass,
 	  applicationShellWidgetClass,
 	  dpy, 0, 0);
   dpy = XtDisplay (toplevel_shell);
   db = XtDatabase (dpy);
-  XtGetApplicationNameAndClass (dpy, &progname, &progclass);
+  XtGetApplicationNameAndClass (dpy, const_cast<char**>(&progname),
+                                const_cast<char**>(&progclass));
 
   QString name = QString::fromLocal8Bit(args->arg(args->count() - 1));
   KXSConfigDialog *dialog=new KXSConfigDialog(args->arg(0), name);
