@@ -86,9 +86,11 @@ int main(int argc, char *argv[])
 
     QPtrList<KXSConfigItem> configItemList;
 
-    QString xmlFile = XSCREENSAVER_HACKS_DIR;
-    xmlFile += "/config/";
-    xmlFile += exeName + ".xml";
+    QString xmlFile = "/doesntexist";
+#ifdef XSCREENSAVER_CONFIG_DIR
+    xmlFile = XSCREENSAVER_CONFIG_DIR;
+#endif
+    xmlFile += "/" + exeName + ".xml";
     if ( QFile::exists( xmlFile ) ) {
 	// We can use the xscreensaver xml config files.
 	KXSXml xmlParser(0);
