@@ -591,14 +591,14 @@ kRockSetup::kRockSetup( QWidget *parent, const char *name )
 	tl1->addWidget(preview);
 
 	KButtonBox *bbox = new KButtonBox(this);
-	button = bbox->addButton( i18n("About"));
+	button = bbox->addButton( i18n("&About"));
 	connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
 	bbox->addStretch(1);
 
-	button = bbox->addButton( i18n("OK"));
+	button = bbox->addButton( i18n("&OK"));
 	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 
-	button = bbox->addButton(i18n("Cancel"));
+	button = bbox->addButton(i18n("&Cancel"));
 	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
 	bbox->layout();
 	tl->addWidget(bbox);
