@@ -1,5 +1,5 @@
 /*
- *	$Id: cdeclient.cpp,v 1.11 2002/08/29 08:59:31 lunakl Exp $
+ *	$Id: cdeclient.cpp,v 1.11.2.2 2003/07/04 18:19:15 fredrik Exp $
  *	
  *	CDE KWin client - emulates the look and feel
  *	of dtwm, the CDE window manager.
@@ -196,6 +196,7 @@ CdeClient::CdeClient( Workspace* ws, WId w, QWidget* parent, const char* name )
     addClientButtons( options->titleButtonsRight() );
 
     titlebarPressed = false;
+    closing = false;
 }
 
 void CdeClient::addClientButtons( const QString& s )
@@ -211,6 +212,7 @@ void CdeClient::addClientButtons( const QString& s )
                     {
                         button[BtnMenu] = new CdeButton( this, "menu", BtnMenu, i18n("Menu") );
                         connect( button[BtnMenu], SIGNAL(pressed()), SLOT(menuButtonPressed()) );
+                        connect( button[BtnMenu], SIGNAL(released()), SLOT(menuButtonReleased()) );
                         titleLayout->addWidget( button[BtnMenu] );
                     }
                     break;
@@ -296,7 +298,13 @@ void CdeClient::menuButtonPressed()
 	button[BtnMenu]->setDown(false);
     }
     else
-	closeWindow();
+       closing = true;
+}
+
+void CdeClient::menuButtonReleased()
+{
+    if( closing )
+        closeWindow();
 }
 
 void CdeClient::resizeEvent( QResizeEvent* e)
@@ -605,7 +613,7 @@ static void readConfig()
     if (s_frameWidth > 10) s_frameWidth = 10;
 }
 
-};
+}
 
 extern "C"
 {
