@@ -1,5 +1,5 @@
 /*
- *	$Id: cdeclient.h,v 1.4 2002/08/27 18:02:58 gallium Exp $
+ *	$Id: cdeclient.h,v 1.4.2.2 2003/07/04 18:19:15 fredrik Exp $
  *	
  *	CDE KWin client - emulates the look and feel
  *	of dtwm, the CDE window manager.
@@ -72,6 +72,7 @@ protected:
 
 protected slots:
     void menuButtonPressed();
+    void menuButtonReleased(); 
 
 private:
     CdeButton* button[BtnCount];
@@ -79,9 +80,10 @@ private:
     QBoxLayout*  titleLayout;
     QSpacerItem* titlebar;
     bool titlebarPressed;
+    bool closing;
 };
 
-};
+}
 
 #endif
 
