@@ -138,6 +138,6 @@ public:
 //	static QBitmap drawRoundRectButtonMask(const QSize& size);
 };
 
-}; // namespace
+} // namespace
 
 #endif
